@@ -9,6 +9,8 @@ package URI::Title::HTML;
 use warnings;
 use strict;
 use HTML::Entities;
+use utf8;
+
 our $CAN_USE_ENCODE;
 BEGIN {
   eval { require Encode; Encode->import('decode') };
@@ -24,34 +26,38 @@ sub title {
   my ($class, $url, $data, $type, $cset) = @_;
 
   my $title;
-  my $match;
+  my $special_case;
+
+  my $default_match = '<title.*?>(.+?)</title';
 
   # special case for the iTMS.
   if ( $INC{'URI/Title/iTMS.pm'} and $url =~ m!phobos.apple.com! and $data =~ m!(itms://[^']*)! ) {
     return URI::Title::iTMS->title($1);
   }
 
-  if ($url =~ /timesonline\.co\.uk/i) {
-    $match = '<span class="headline">(.*?)<';
-
-  } elsif ($url =~ /use\.perl\.org\/~([^\/]+).*journal\/\d/i) {
-    $match = '<FONT FACE="geneva,verdana,sans-serif" SIZE="1"><B>(.*?)<';
+  if ($url =~ /use\.perl\.org\/~([^\/]+).*journal\/\d/i) {
+    $special_case = '<FONT FACE="geneva,verdana,sans-serif" SIZE="1"><B>(.+?)<';
     $title = "use.perl journal of $1 - ";
 
   } elsif ($url =~ /(pants\.heddley\.com|dailychump\.org).*#(.*)$/i) {
     my $id = $2;
-    $match = 'id="a'.$id.'.*?></a>(.*?)<';
+    $special_case = 'id="a'.$id.'.*?></a>(.+?)<';
     $title = "pants daily chump - ";
 
   } elsif ($url =~ /paste\.husk\.org/i) {
-    $match = 'Summary: (.*?)<';
+    $special_case = 'Summary: (.+?)<';
     $title = "paste - ";
 
-  } elsif ($url =~ /independent\.co\.uk/i) {
-    $match = '<h1 class=head1>(.*?)<';
+  } elsif ($url =~ /twitter.com\/(.*?)\/statuses\/\d+/i) {
+    $special_case = '<div class="desc">\s*<p>\s*(.+?)\s*</p';
+    $title = "twitter by $1 - ";
 
-  } else {
-    $match = '<title.*?>(.*?)</title';
+  } elsif ($url =~ /independent\.co\.uk/i) {
+    $special_case = '<h1 class=head1>(.+?)<';
+
+  } elsif ($url =~ /www\.hs\.fi\/english\/article/i) {
+    $special_case = '<h1>(.+?)</h1>';
+  
   }
 
 
@@ -60,12 +66,22 @@ sub title {
     $cset = lc($1);
   }
 
-  $data =~ /$match/ims or return; # "Can't find title";
-  $title .= $1;
-
   if ( $CAN_USE_ENCODE ) {
-    $title = eval { decode('utf-8', $title, 1) } ||  eval { decode($cset, $title) } || $title;
+    $data = eval { decode('utf-8', $data, 1) } ||  eval { decode($cset, $data, 1) } || $data;
   }
+  
+
+  my $found_title;
+  if ($special_case) {
+    ($found_title) = $data =~ /$special_case/ims;
+  }
+  unless ($found_title) {
+    ($found_title) = $data =~ /$default_match/ims;
+  }
+  return unless $found_title;
+  $found_title =~ s/<.*?>//g;
+  $title .= $found_title;
+
 
   $title =~ s/\s+$//;
   $title =~ s/^\s+//;
